import os
from datetime import datetime
import _queue_sender


def _generate_message(level: str, message: str):
    _queue_sender.send_to_queue("logs", {'level': level, 'message': message,
                                         'timestamp': datetime.timestamp(
                                             datetime.now())})
    return "Message sended"


def debug(message: str):
    """
    Log a message with debug level

    :param message: the message to log
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message("debug", message)
    else:
        print(message)


def info(message: str):
    """
    Log a message with info level

    :param message: the message to log
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message("info", message)
    else:
        print(message)


def warning(message: str):
    """
    Log a message with warning level

    :param message: the message to log
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message("warning", message)
    else:
        print(message)


def error(message: str):
    """
    Log a message with error level

    :param message: the message to log
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message("error", message)
    else:
        print(message)


def critical(message: str):
    """
    Log a message with critical level

    :param message: the message to log
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message("critical", message)
    else:
        print(message)


if __name__ == '__main__':
    debug("test")
    info("test")
    warning("test")
    error("test")
    os.environ['BWI_INFRA'] = "trou"
    debug("test")
    info("test")
    warning("test")
    error("test")



import json
import os
import pika

RABBIT_HOST = os.environ.get('BWI_RABBIT_HOSTNAME')
RABBIT_VHOST = os.environ.get('RABBIT_VHOST')
RABBIT_USERID = os.environ.get('BWI_RABBIT_USER')
RABBIT_PASSWORD = os.environ.get('BWI_RABBIT_PASSWORD')
RABBIT_CREDENTIALS = pika.PlainCredentials(RABBIT_USERID, RABBIT_PASSWORD)
_rabbit_channel = None


def get_connection():
    global _rabbit_channel
    if _rabbit_channel is not None:
        return _rabbit_channel
    rabbit_connection = pika.BlockingConnection(
        pika.ConnectionParameters(host=RABBIT_HOST,
                                  credentials=RABBIT_CREDENTIALS,
                                  virtual_host=RABBIT_VHOST))
    _rabbit_channel = rabbit_connection.channel()
    return _rabbit_channel


def send_to_queue(queue_name: str, message: str):
    message = json.dumps(message)
    get_connection().basic_publish(exchange='',
                                   routing_key=queue_name,
                                   body=message)
    print('Sent message "' + message + '" to queue "' + queue_name + '"')



import os
from datetime import datetime
import _queue_sender


def _generate_message(type: str, val: float, value: float):
    _queue_sender.send_to_queue("metrics", {'type': type, 'value': val,
                                            'timestamp': datetime.timestamp(
                                                datetime.now())})
    return "Message sended"


def inc(name: str, val: float):
    """
    Store an inc metric value
    :param name: the name of the metric
    :param val: the value of the current action
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message('inc', name, val)
    else:
        print(name, val)


def dec(name: str, val: float):
    """
    Store a dec metric value
    :param name: the name of the metric
    :param value: the value of the current action
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message('dec', name, val)
    else:
        print(name, val)


def value(name: str, val: float):
    """
    Store a numeric value
    :param name: the name of the metric
    :param value: the value of the current action
    """
    if os.environ.get('BWI_INFRA') is not None:
        _generate_message('value', name, val)
    else:
        print(name, val)


if __name__ == '__main__':
    inc("test", 1)
    dec("test", 1)
    value("test", 1)
    os.environ['BWI_INFRA'] = "trou"
    inc("test", 1)
    dec("test", 1)
    value("test", 1)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="bwi",
    version="0.0.6",
    author="BWI",
    author_email="contact@bwi-project.com",
    description="Package to add bwi methods into your project",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/bwi-gpe/bwi-lib",
    packages=setuptools.find_packages(),
    classifiers=[],
    python_requires='>=3.0',
)
